@@ -17,6 +17,7 @@ PLUGIN_DEFAULTS = {
     "mockserver-bind": "127.0.0.1",
     "mockserver-host": "localhost",
     "mockserver-relay": "",
+    "mockserver-relay-remote-base-url": "https://api.wandb.ai",
 }
 
 
@@ -59,12 +60,33 @@ class Backend:
     def start(self):
         if self._args.dryrun:
             return
-        if self._args.live:
-            return
         mockserver_bind = self._params["mockserver-bind"]
         mockserver_host = self._params["mockserver-host"]
         mockserver_relay = self._params["mockserver-relay"]
+        mockserver_relay_remote_base_url = self._params[
+            "mockserver-relay-remote-base-url"
+        ]
         # TODO: consolidate with github.com/wandb/client:tests/conftest.py
+
+        # if we are using live mode. force mock_server plugin defaults
+        if self._args.live:
+            mockserver_bind = "0.0.0.0"
+            mockserver_host = "__auto__"
+            mockserver_relay = "true"
+            base_url = os.environ.get("WANDB_BASE_URL", "https://api.wandb.ai")
+            mockserver_relay_remote_base_url = base_url
+
+            # setup api key
+            api_key = os.environ.get("WANDB_API_KEY")
+            if not api_key:
+                auth = requests.utils.get_netrc_auth(base_url)
+                if not auth:
+                    raise ValueError(
+                        f"must configure api key by env or in netrc for {base_url}"
+                    )
+                api_key = auth[-1]
+                os.environ["WANDB_API_KEY"] = api_key
+
         port = self._free_port(mockserver_bind)
 
         # get external ip
@@ -80,6 +102,7 @@ class Backend:
         env["MOCKSERVER_BIND"] = mockserver_bind
         if mockserver_relay:
             env["MOCKSERVER_RELAY"] = mockserver_relay
+            env["MOCKSERVER_RELAY_REMOTE_BASE_URL"] = mockserver_relay_remote_base_url
         worker_id = 1
         logfname = os.path.join(
             self._yc._cfg._cfroot,
@@ -119,7 +142,7 @@ class Backend:
                 if res.status_code == 200:
                     started = True
                     break
-                print("INFO: Attempting to connect but got: %s" % res)
+                print(f"INFO: Attempting to connect but got: {res}")
             except requests.exceptions.RequestException:
                 print(
                     "INFO: Timed out waiting for server to start...",
@@ -131,17 +154,18 @@ class Backend:
                 else:
                     raise ValueError("Server failed to start.")
         if started:
-            print(
-                "INFO: Mock server listing on {} see {}".format(server._port, logfname)
-            )
+            print(f"INFO: Mock server listing on {server._port}, see {logfname}")
         else:
             server.terminate()
-            print("ERROR: Server failed to launch, see {}".format(logfname))
+            print(f"ERROR: Server failed to launch, see {logfname}")
             raise Exception("problem")
 
         os.environ["WANDB_BASE_URL"] = f"http://{mockserver_host}:{port}"
         if not mockserver_relay:
             os.environ["WANDB_API_KEY"] = DUMMY_API_KEY
+        else:
+            # os.environ["WANDB_BASE_URL"] = mockserver_relay_remote_base_url
+            pass
         os.environ[
             "WANDB_SENTRY_DSN"
         ] = f"http://fakeuser@{mockserver_host}:{port}/5288891"
